"""Main loop."""
from queue import Queue
from typing import Protocol

from system_configurator.core.api.api_mqtt.entities import IMqttMessage
from system_configurator.core.api.api_mqtt.msg_handlers import IMsgHandler


class IMainLoop(Protocol):
    """Interface for Main loop.

    Args:
        msg_queue (Queue[IMqttMessage]): que for receive message.
        msg_handler (IMsgHandler): Class for proceed message.
    """

    def __init__(self, msg_queue: Queue[IMqttMessage], msg_handler: IMsgHandler) -> None:
        ...

    def start(self) -> None:
        """Start main loop."""


class MainLoop():
    """Main loop.

    Receive messages from mqtt queue and sends for further processing.

    Args:
        msg_queue (Queue[IMqttMessage]): que for receive message.
        msg_handler (IMsgHandler): Class for proceed message.
    """

    def __init__(self, msg_queue: Queue[IMqttMessage], msg_handler: IMsgHandler) -> None:
        self.msg_queue = msg_queue
        self._msg_handler = msg_handler

    def start(self) -> None:
        """Start main loop."""
        while True:
            msg = self.msg_queue.get()
            self._msg_handler.handle_msg(msg=msg)
