"""Содержит интерфейсы для создания репозиториев."""
from typing import Generic, Protocol, TypeVar

from sqlalchemy.orm import Session


TSchema = TypeVar("TSchema")


class IRepository(Protocol, Generic[TSchema]):
    """Базовый интерфейс репозитория."""

    def create(self, schema: TSchema) -> TSchema:
        """Создает объект модели в репозитории.

        Args:
            schema (TSchema): Объект.

        Returns:
            TSchema: Объект.
        """
        ...

    def delete(self, schema: TSchema) -> None:
        """Удаляет объект модели из репозитория.

        Args:
            schema (TSchema): Объект.
        """
        ...

    def update(self, schema: TSchema) -> TSchema:
        """Обновляет объект модели в репозитории.

        Args:
            schema (TSchema): Объект.

        Returns:
            TSchema: Объект.
        """
        ...

    def get(self, name: str) -> TSchema:
        """Возвращает объект модели из репозитория по его имени.

        Args:
            name (str): Имя Объекта.

        Returns:
            TSchema: Объект.
        """
        ...

    def get_list(self) -> list[TSchema]:
        """Возвращает все объекты из репозитория.

        Returns:
            list[TSchema]: Список всех объектов репозитория..
        """
        ...


class ISqlAlchemyRepositoryFabric(Protocol, Generic[TSchema]):
    """Интерфейс для фабрики по созданию репозиториев SqlAlchemy."""

    def __call__(self, session: Session) -> IRepository[TSchema]:
        """Создает репозиторий SqlAlchemy.

        Args:
            session (Session): SqlAlchemy сессия.

        Returns:
            IRepository[TSchema]: Репозиторий.
        """
        ...
