"""Содержит все необходимое для создания событий mqtt publisher'a файловой системы."""
from typing import Callable

from watchdog.observers.polling import PollingObserver
from watchdog.events import FileSystemEventHandler

from system_configurator.core.api.api_mqtt.publishers import ObserverObject


class FsEventCallback(FileSystemEventHandler):
    """Обратные вызовы событий файловой системы.

    Args:
        callback(Callable[[list[ObserverObject]], None]): обратный вызов mqtt publisher'a.
    """

    def __init__(self, callback: Callable[[ObserverObject], None]) -> None:
        self.callback = callback

    def on_modified(self, event):
        """Обратный вызов события модификации файла.

        Запускает обратный вызов mqtt publisher'a.
        """
        self.callback(ObserverObject('file', event.src_path))

    def on_created(self, event):
        """Обратный вызов события создания файла.

        Запускает обратный вызов mqtt publisher'a.
        """
        self.callback(ObserverObject('file', event.src_path))


class FsEventCreator():
    """Создатель событий для файловой системы.

    По наступлению события происходит запуск обратного вызова по отправке mqtt сообщения.
    """

    def create(self, callback: Callable[[ObserverObject], None],  observing_objs: set[ObserverObject]) -> None:
        """Создает события для файловой системы.

        По наступлению события происходит запуск обратного вызова по отправке mqtt сообщения.

        Args:
            callback (Callable[[list[ObserverObject]], None]): Обратный вызов по отправке mqtt сообщения.
            observing_objs (set[ObserverObject]): Наблюдаемый объект.
        """
        event_handler = FsEventCallback(callback)
        observer = PollingObserver()
        for observing_obj in observing_objs:
            if observing_obj.type == 'file':
                observer.schedule(event_handler, observing_obj.value, recursive=False)
        observer.start()
