"""Утилиты для работы с файлами."""
import os
import pathlib
from typing import Any, Union

from jinja2 import Environment, FileSystemLoader, Template

from system_configurator import settings


def save_config(data: Union[list[str], dict[str, Any]], template: str, config: str, config_path: str) -> None:
    """Save config file.

    Filling up a configuration file template a in temp directory then move it to a target location.

    Args:
        data (Union[list[str], dict[str, Any]]):    data to fill in the config file
        template (str):                             name of template config file
        config (str):                               target config file
        config_path (str):                          path to target config file
    """
    template_dir: str = settings.TEMPLATES_DIR
    temp_dir: str = settings.TEMP_DIR
    env = Environment(loader=FileSystemLoader(template_dir))
    jinja_template: Template = env.get_template(template)

    with open(f'{temp_dir}{config}', 'w') as config_file:
        config_file.write(jinja_template.render(data))

    os.system(f'sudo cp {temp_dir}{config} {config_path}/{config}')
    os.system(f'sudo rm -rf {temp_dir}{config}')


def move_file_with_sudo(src_filepath: Union[str, pathlib.Path], dst_filepath: Union[str, pathlib.Path]) -> None:
    """Перемещает файл c sudo правами.

    Args:
        src_filepath (Union[str, pathlib.Path]): откуда.
        dst_filepath (Union[str, pathlib.Path]): куда.
    """
    os.system(f'sudo mv {src_filepath} {dst_filepath}')