"""SqlAlchemy Models."""
from sqlalchemy.ext.associationproxy import association_proxy
from sqlalchemy import Column, ForeignKey, Integer, String
from sqlalchemy.orm import relationship

from system_configurator.core.db.database import Base


class SpCertType(Base):
    """Справочник содержащий все доступные типы сертификатов."""

    __tablename__ = 'sp_cert_type'

    id = Column(Integer, primary_key=True, unique=True)
    name = Column(String(50), nullable=False, unique=True)


class SpParam(Base):
    """Справочник содержащий все доступные параметры."""

    __tablename__ = 'sp_param'

    id = Column(Integer, primary_key=True, unique=True)
    name = Column(String(50), nullable=False, unique=True)


class SpCertParam(Base):
    """Справочник содержащий сопоставление типа сертификата и доступных ему параметров."""

    __tablename__ = 'sp_cert_param'

    id = Column(Integer, primary_key=True, unique=True)
    id_sp_cert_type = Column(Integer, ForeignKey('sp_cert_type.id'))
    id_sp_param = Column(Integer, ForeignKey('sp_param.id'))


class Certificate(Base):
    """Содержит список всех сертификатов."""

    __tablename__ = 'certificate'

    id = Column(Integer, primary_key=True, unique=True)
    name = Column(String(50), nullable=False, unique=True)
    public_bytes = Column(String, nullable=False, unique=False)
    id_sp_c_type = Column(Integer, ForeignKey('sp_cert_type.id'))

    cert_type = relationship('SpCertType', lazy='subquery', viewonly=True, load_on_pending=True)
    params = relationship('CertParam', lazy='subquery', uselist=True)


class CertParam(Base):
    """Содержит список всех параметров сертификатов с их значениями."""

    __tablename__ = 'cert_param'

    id = Column(Integer, primary_key=True, unique=True)
    id_cert = Column(Integer, ForeignKey('certificate.id', ondelete='CASCADE'))
    id_sp_c_p = Column(Integer, ForeignKey('sp_cert_param.id', ondelete='CASCADE'))
    value = Column(String, nullable=False)

    sp_param = relationship(
        'SpParam', secondary='sp_cert_param', uselist=False, lazy='subquery',  viewonly=True, load_on_pending=True,
    )
    name = association_proxy('sp_param', 'name')
