"""Репозитории для доступа к данным."""
from typing import Literal, Protocol, Union, overload

from system_configurator.network.domain.models import IModemIface, IWiredIface


class IEthernetRepository(Protocol):
    """Интерфейс репозитория с ethernet интерфейсами."""

    # Список с измененными интерфейсами.
    dirty: set[Union[IWiredIface, IModemIface]]

    @overload
    def get(self, iface_type: Literal['wired']) -> IWiredIface: ...
    @overload
    def get(self, iface_type: Literal['modem']) -> IModemIface: ...

    def get(self, iface_type: Literal['wired', 'modem']) -> Union[IWiredIface, IModemIface]:
        """Получить объект доменной модели интерфейса.

        Принимает тип интерфейса и исходя из него возвращает нужный объект.

        Args:
            iface_type (Literal['wired', 'modem']): Тип интерфейса.

        Returns:
            Union[IWiredIface, IModemIface]: Объект доменной модели интерфейса.
        """
        ...

    def update(self, iface: Union[IWiredIface, IModemIface]) -> None:
        """Обновить интерфейс.

        Args:
            iface (Union[IWiredIface, IModemIface]): Объект доменной модели интерфейса.
        """
        ...
