"""Router for network services."""
from typing import Type
from system_configurator.core.api.api_mqtt.msg_handlers import CommandRunner, ISetSystemParamCommand
from system_configurator.core.api.api_mqtt.router import TRouter
from system_configurator.network.api.api_mqtt.router_commands import (
    SetApnCredentialToModemIfaceCommand,
    SetDnsCredentialToModemIfaceCommand,
    SetDnsCredentialToWiredIfaceCommand,
    SetIpCredentialToModemIfaceCommand,
    SetIpCredentialToWiredIfaceCommand,
)
from system_configurator.network.adapters.utils import (
    AddNetworkRouteViaIoctlCommand,
    DelNetworkRouteViaIoctlCommand,
    SaveHostnameConfigCommand,
    SaveNetworkInterfaceConfig,
    SaveNetworkRoutesConfigCommand,
    SetDnsServersCommand,
    SetHostnameCommand,
    SetIPAddressViaIoctl,
    SetNetmaskViaIoctl,
)


command_network_fabric: dict[str, Type[ISetSystemParamCommand]] = {
    # Network
    'set_ip': SetIPAddressViaIoctl,  # TODO: Объединить в change_eht1_ip_address
    'set_netmask': SetNetmaskViaIoctl,  # TODO: Объединить
    'add_network_route': AddNetworkRouteViaIoctlCommand,
    'delete_network_route': DelNetworkRouteViaIoctlCommand,
    'change_hostname': SetHostnameCommand,  # TODO: Не нужно
    'set_dns_servers': SetDnsServersCommand,
    'save_network_interface_config': SaveNetworkInterfaceConfig,
    'save_network_routes_config': SaveNetworkRoutesConfigCommand,
    'save_hostname_config': SaveHostnameConfigCommand,  # TODO: Не нужно
}
command_network_runner = CommandRunner(command_network_fabric)


router: TRouter = {
    'lm/system_settings/network': command_network_runner,
    'lm/system_settings/network/interfaces/wired/set_ip_credential': SetIpCredentialToWiredIfaceCommand(),
    'lm/system_settings/network/interfaces/wired/set_dns_credential': SetDnsCredentialToWiredIfaceCommand(),
    'lm/system_settings/network/interfaces/modem/set_ip_credential': SetIpCredentialToModemIfaceCommand(),
    'lm/system_settings/network/interfaces/modem/set_dns_credential': SetDnsCredentialToModemIfaceCommand(),
    'lm/system_settings/network/interfaces/modem/set_apn_credential': SetApnCredentialToModemIfaceCommand(),
}
