"""Package settings."""
import os


DEBUG = True

PUBLISHER_LOOP_TIMEOUT = 0.5

MQTT_CLIENT_NAME = 'lm_system_configurator_service'

SERVICE_TOPICS = {
    'error': 'lm/system_configurator/error',
}

MODULES = [
    'network',
    'timedate',
    'external_access',
]


SQLALCHEMY_DATABASE_URL = "sqlite:///db/system_config.db"

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

TEMPLATES_DIR = os.path.join(BASE_DIR, 'templates/')

TEMP_DIR = os.path.join(BASE_DIR, 'tmp/')

INTERFACE_CONFIG_PREFIX = 10

MODEM_DEVICE_PATH = '/dev/cdc-wdm0'

NGINX_CONFIG_TEMPLATE = 'nginx.conf'
NGINX_CONFIG_PATH = '/home/lightmaster/lightmaster/conf/nginx/lightmaster.conf'

SSL_CERT_PATH = '/etc/ssl/certs/'
SSL_KEY_PATH = '/etc/ssl/private/'
SSL_CERT_EXTENSION = '.crt'
SSL_KEY_EXTENSION = '.key'

LOGGING_CONFIG = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'standard': {
            'format': '%(asctime)s [%(levelname)s] lm_system_configurator_service: %(message)s',
        },
    },
    'handlers': {
        'debug_console_handler': {
            'level': 'DEBUG' if DEBUG else 'INFO',
            'formatter': 'standard',
            'class': 'logging.StreamHandler',
            'stream': 'ext://sys.stdout',
        },
        'file_handler': {
            'level': 'DEBUG' if DEBUG else 'INFO',
            'formatter': 'standard',
            'class': 'logging.handlers.RotatingFileHandler',
            'filename': 'lm_system_configurator_service.log',
            'mode': 'a',
            'maxBytes': 3*1024*1024,
            'backupCount': 3,
        },
    },
    'loggers': {
        'system_configurator': {
            'handlers': ['debug_console_handler', 'file_handler'],
            'level': 'DEBUG' if DEBUG else 'INFO',
            'propagate': True,
        },
        '__main__': {
            'handlers': ['debug_console_handler', 'file_handler'],
            'level': 'DEBUG' if DEBUG else 'INFO',
            'propagate': True,
        },
    },
}
