"""Actions base."""
from typing import Literal, TypeVar, runtime_checkable, Protocol


TPossibleActionTypes = Literal['send_mqtt_msg_raw', 'send_trigger_to_mqtt']
T = TypeVar('T')


@runtime_checkable
class IMqttMsgParams(Protocol):
    """Интерфейс объекта содержащего параметры для отправки mqtt сообщения.

    Mqtt сообщение формируется без изменения payload.

    Args:
        topic (str): Mqtt topic для отправки сообщения.
        payload (str): raw payload для сообщения
        retain (bool): Оставлять ли сообщение в топике постоянно.
    """
    topic: str
    payload: str
    retain: bool


@runtime_checkable
class IAction(Protocol[T]):
    """Интерфейс объекта с настройками действия.

    Может принимать различные классы параметров. Класс параметров должен совпадать с типом действия.

    Args:
        name (str) - Имя действия.
        tr_type (str) - Тип действия.
        params (T) - Класс параметров. Должен совпадать с типом действия.
    """

    name: str
    action_type: TPossibleActionTypes
    params: T
