"""Contains custom exceptions."""
from typing import Any, Optional


class Error(Exception):
    """Custom error class.

    Attributes:
        message - explanation of the error.
        data - any other data.
    """

    default_message: str = ''

    def __init__(self, message: Optional[str] = None, data: Any = None, *args: object) -> None:
        """Save initial variables."""
        self.message: str = message if message else self.default_message
        self.data = data
        super().__init__(self.message, self.data, *args)


class ValidationException(Error):
    """Validations errors."""


class NotFoundException(Error):
    """Not found errors."""

    default_message: str = 'Not Found'


class ParseException(Error):
    """Base class for parsing errors."""


class NotArtNetException(ParseException):
    """Exception raises when frame is not ArtNet frame."""

    default_message = 'This is not ArtNet file.'


class SocketNotFoundError(Error):
    """Exception."""

    default_message = 'Socket not found.'


class NetworkTypeIsNotSupported(Error):
    """Exception run if network type in the trigger is not support."""

    default_message = 'Network type is not supported.'


class NetworkAddressAlreadyInUse(Error):
    """Exception run if the network address already in use."""

    default_message = 'Address already in use.'


class SocketError(Error):
    """Exception run if the network socket raise error."""

    default_message = 'Socket error.'


class AlreadyExistError(Error):
    """Exception run if object already exist."""

    default_message = 'Object already exist.'
