"""Callbacks for db operations."""
from sqlalchemy import event
from sqlalchemy.orm import Session

from triggers.commands.publisher_commands import send_action_list, send_relations_list, send_trigger_list


def after_commit_table_publisher(session: Session) -> None:
    """Публикует записи из таблиц triggers и actions."""
    send_trigger_list()
    send_action_list()


def send_action_list_db_listen_adapter(session: Session) -> None:
    """Адаптер для запуска функции send_action_list в SqlAlchemy listens."""
    send_action_list()


def send_trigger_list_db_listen_adapter(session: Session) -> None:
    """Адаптер для запуска функции send_trigger_list в SqlAlchemy listens."""
    send_trigger_list()


def send_relation_list_db_listen_adapter(session: Session) -> None:
    """Адаптер для запуска функции send_trigger_list в SqlAlchemy listens."""
    send_relations_list()


def create_db_listens_publishes_tables_to_mqtt_after_db_commit() -> None:
    """Создает listen который публикует записи из таблиц triggers и actions каждый раз после комита в БД."""
    event.listen(Session, 'after_commit', send_action_list_db_listen_adapter)
    event.listen(Session, 'after_commit', send_trigger_list_db_listen_adapter)
    event.listen(Session, 'after_commit', send_relation_list_db_listen_adapter)
