"""Module settings."""
from typing import Any

DEBUG = True

ARTNET_DEFAULT_PORT = 6454
ARTNET_MASQUERADE_DEFAULT_PORT = 7777

PUBLISHER_LOOP_TIMEOUT = 0.5

SERVICE_TOPICS = {
    'error': 'lm/trigger_service/error',
}

ServiceLocator: dict[str, Any] = {}


LOGGING_CONFIG = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'standard': {
            'format': '%(asctime)s [%(levelname)s] lm_trigger_service: %(message)s',
        },
    },
    'handlers': {
        'debug_console_handler': {
            'level': 'DEBUG' if DEBUG else 'INFO',
            'formatter': 'standard',
            'class': 'logging.StreamHandler',
            'stream': 'ext://sys.stdout',
        },
        'file_handler': {
            'level': 'DEBUG' if DEBUG else 'INFO',
            'formatter': 'standard',
            'class': 'logging.handlers.RotatingFileHandler',
            'filename': 'lm_trigger_service.log',
            'mode': 'a',
            'maxBytes': 3*1024*1024,
            'backupCount': 3,
        },
    },
    'loggers': {
        'triggers': {
            'handlers': ['debug_console_handler', 'file_handler'],
            'level': 'DEBUG' if DEBUG else 'INFO',
            'propagate': True,
        },
        '__main__': {
            'handlers': ['debug_console_handler', 'file_handler'],
            'level': 'DEBUG' if DEBUG else 'INFO',
            'propagate': True,
        },
    }
}
