"""Main loop."""
import logging
from queue import Queue
from typing import Protocol

from paho.mqtt.client import MQTTMessage

from updater.core.msg_handlers import IMsgHandler


logger = logging.getLogger(__name__)


class IMainLoop(Protocol):
    """Interface for Main loop.

    Args:
        msg_queue (Queue[MQTTMessage]): que for receive message.
        msg_handler (IMsgHandler): Class for proceed message.
    """

    def __init__(self, msg_queue: Queue[MQTTMessage], msg_handler: IMsgHandler) -> None:
        ...

    def start(self) -> None:
        """Start main loop."""


class MainLoop():
    """Main loop.

    Receive messages from mqtt queue and sends for further processing.

    Args:
        msg_queue (Queue[MQTTMessage]): que for receive message.
        msg_handler (IMsgHandler): Class for proceed message.
    """

    def __init__(self, msg_queue: Queue[MQTTMessage], msg_handler: IMsgHandler) -> None:
        self.msg_queue = msg_queue
        self._msg_handler = msg_handler

    def start(self) -> None:
        """Start main loop."""
        logger.debug('Logic Main Loop has been started.')
        while True:
            msg = self.msg_queue.get()
            self._msg_handler.handle_msg(msg=msg)
