"""Pydantic Schemas."""

import pathlib
from typing import Optional
from pydantic import BaseModel, Field


class VersionSchema(BaseModel):
    """Schema with Information about current installed versions."""

    id: Optional[int]
    version: str = Field(..., max_length=50)
    subversion: str = Field(None, max_length=50)
    module: str = Field(..., max_length=50)
    description: Optional[str]

    class Config:
        """Schema config."""
        orm_mode = True


class ModuleNameSchema(BaseModel):
    """Schema with Information about module name."""

    module: str = Field(..., max_length=50)

    class Config:
        """Schema config."""
        orm_mode = True


class UpdateSchema(BaseModel):
    """Schema with Information about update."""

    id: Optional[int]
    version: str = Field(..., max_length=50)
    status: str
    filename: str
    update_path: str
    extracted_path: Optional[str]
    backup_path: Optional[str]
    description: Optional[str]

    class Config:
        """Schema config."""
        orm_mode = True


class IdInputSchema(BaseModel):
    """Schema for validating id input data."""

    id: int


class UpdateFileSchema(BaseModel):
    """Schema for validating initial update input data.

    file: pathlib.Path - path to update file
    """

    file: pathlib.Path
